# flake8: noqa

# import apis into api package
from syndb_api_client.api.auth_api import AuthApi
from syndb_api_client.api.benchmark_api import BenchmarkApi
from syndb_api_client.api.cilogon_api import CilogonApi
from syndb_api_client.api.dataset_api import DatasetApi
from syndb_api_client.api.default_api import DefaultApi
from syndb_api_client.api.external_api import ExternalApi
from syndb_api_client.api.github_api import GithubApi
from syndb_api_client.api.google_api import GoogleApi
from syndb_api_client.api.io_api import IoApi
from syndb_api_client.api.metadata_api import MetadataApi
from syndb_api_client.api.neurodata_api import NeurodataApi
from syndb_api_client.api.oauth_api import OauthApi
from syndb_api_client.api.orcid_api import OrcidApi
from syndb_api_client.api.tag_api import TagApi
from syndb_api_client.api.user_api import UserApi



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from syndb_api_client.models.data_license import DataLicense
from syndb_api_client.models.model_animal import ModelAnimal
from syndb_api_client.models.mutation_model_create_read import MutationModelCreateRead
from typing_extensions import Annotated, Self


class SingleDatasetSchemaNoBrainRegion(BaseModel):
    """
    SingleDatasetSchemaNoBrainRegion
    """  # noqa: E501

    authorized_group_names: Optional[List[StrictStr]] = None
    dataset_collection_names: Optional[List[StrictStr]] = None
    publication_dois: Optional[List[StrictStr]] = None
    id: StrictStr
    label: Annotated[str, Field(strict=True, max_length=120)]
    data_license: Optional[DataLicense] = None
    animal: ModelAnimal
    mutations: Optional[List[MutationModelCreateRead]] = None
    microscopy: StrictStr
    notes: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "authorized_group_names",
        "dataset_collection_names",
        "publication_dois",
        "id",
        "label",
        "data_license",
        "animal",
        "mutations",
        "microscopy",
        "notes",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SingleDatasetSchemaNoBrainRegion from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in mutations (list)
        _items = []
        if self.mutations:
            for _item in self.mutations:
                if _item:
                    _items.append(_item.to_dict())
            _dict["mutations"] = _items
        # set to None if authorized_group_names (nullable) is None
        # and model_fields_set contains the field
        if self.authorized_group_names is None and "authorized_group_names" in self.model_fields_set:
            _dict["authorized_group_names"] = None

        # set to None if dataset_collection_names (nullable) is None
        # and model_fields_set contains the field
        if self.dataset_collection_names is None and "dataset_collection_names" in self.model_fields_set:
            _dict["dataset_collection_names"] = None

        # set to None if publication_dois (nullable) is None
        # and model_fields_set contains the field
        if self.publication_dois is None and "publication_dois" in self.model_fields_set:
            _dict["publication_dois"] = None

        # set to None if mutations (nullable) is None
        # and model_fields_set contains the field
        if self.mutations is None and "mutations" in self.model_fields_set:
            _dict["mutations"] = None

        # set to None if notes (nullable) is None
        # and model_fields_set contains the field
        if self.notes is None and "notes" in self.model_fields_set:
            _dict["notes"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SingleDatasetSchemaNoBrainRegion from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "authorized_group_names": obj.get("authorized_group_names"),
                "dataset_collection_names": obj.get("dataset_collection_names"),
                "publication_dois": obj.get("publication_dois"),
                "id": obj.get("id"),
                "label": obj.get("label"),
                "data_license": obj.get("data_license"),
                "animal": obj.get("animal"),
                "mutations": (
                    [MutationModelCreateRead.from_dict(_item) for _item in obj["mutations"]]
                    if obj.get("mutations") is not None
                    else None
                ),
                "microscopy": obj.get("microscopy"),
                "notes": obj.get("notes"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.6.14"

# import apis into sdk package
from syndb_api_client.api.auth_api import AuthApi
from syndb_api_client.api.benchmark_api import BenchmarkApi
from syndb_api_client.api.cilogon_api import CilogonApi
from syndb_api_client.api.dataset_api import DatasetApi
from syndb_api_client.api.default_api import DefaultApi
from syndb_api_client.api.external_api import ExternalApi
from syndb_api_client.api.github_api import GithubApi
from syndb_api_client.api.google_api import GoogleApi
from syndb_api_client.api.io_api import IoApi
from syndb_api_client.api.metadata_api import MetadataApi
from syndb_api_client.api.neurodata_api import NeurodataApi
from syndb_api_client.api.oauth_api import OauthApi
from syndb_api_client.api.orcid_api import OrcidApi
from syndb_api_client.api.tag_api import TagApi
from syndb_api_client.api.user_api import UserApi
from syndb_api_client.api_client import ApiClient

# import ApiClient
from syndb_api_client.api_response import ApiResponse
from syndb_api_client.configuration import Configuration
from syndb_api_client.exceptions import (
    ApiAttributeError,
    ApiException,
    ApiKeyError,
    ApiTypeError,
    ApiValueError,
    OpenApiException,
)

# import models into sdk package
from syndb_api_client.models.animal_model_create import AnimalModelCreate
from syndb_api_client.models.bearer_response import BearerResponse
from syndb_api_client.models.body_verify_request_token_user_auth_request_verify_token_post import (
    BodyVerifyRequestTokenUserAuthRequestVerifyTokenPost,
)
from syndb_api_client.models.body_verify_verify_user_auth_verify_post import BodyVerifyVerifyUserAuthVerifyPost
from syndb_api_client.models.brain_region_by_dataset_response import BrainRegionByDatasetResponse
from syndb_api_client.models.brain_region_create_read import BrainRegionCreateRead
from syndb_api_client.models.brain_region_read import BrainRegionRead
from syndb_api_client.models.brain_structure import BrainStructure
from syndb_api_client.models.create_dataset_collection_multi_brain_region import CreateDatasetCollectionMultiBrainRegion
from syndb_api_client.models.create_read_dataset_collection_model import CreateReadDatasetCollectionModel
from syndb_api_client.models.cultural_model_animal_name import CulturalModelAnimalName
from syndb_api_client.models.data_license import DataLicense
from syndb_api_client.models.dataset_error_detail import DatasetErrorDetail
from syndb_api_client.models.dataset_error_model import DatasetErrorModel
from syndb_api_client.models.dataset_filter_schema import DatasetFilterSchema
from syndb_api_client.models.dataset_id2_syndb_tables import DatasetId2SyndbTables
from syndb_api_client.models.dataset_search_result_schema import DatasetSearchResultSchema
from syndb_api_client.models.dataset_tag_search_schema import DatasetTagSearchSchema
from syndb_api_client.models.dataset_upload_benchmark_result_schema import DatasetUploadBenchmarkResultSchema
from syndb_api_client.models.dataset_upload_benchmark_results_schema import DatasetUploadBenchmarkResultsSchema
from syndb_api_client.models.detail import Detail
from syndb_api_client.models.error_model import ErrorModel
from syndb_api_client.models.file_error_detail import FileErrorDetail
from syndb_api_client.models.file_error_model import FileErrorModel
from syndb_api_client.models.gene_expression import GeneExpression
from syndb_api_client.models.http_validation_error import HTTPValidationError
from syndb_api_client.models.id2_label_response import Id2LabelResponse
from syndb_api_client.models.id_response import IdResponse
from syndb_api_client.models.ids_response import IdsResponse
from syndb_api_client.models.location_inner import LocationInner
from syndb_api_client.models.microscopy_create_read import MicroscopyCreateRead
from syndb_api_client.models.model_animal import ModelAnimal
from syndb_api_client.models.multi_brain_region_dataset_definition import MultiBrainRegionDatasetDefinition
from syndb_api_client.models.mutation_model_create_read import MutationModelCreateRead
from syndb_api_client.models.mutation_model_read import MutationModelRead
from syndb_api_client.models.neuroanatomical_direction import NeuroanatomicalDirection
from syndb_api_client.models.neurodata_download_benchmark_result_schema import NeurodataDownloadBenchmarkResultSchema
from syndb_api_client.models.neurodata_download_benchmark_results_schema import NeurodataDownloadBenchmarkResultsSchema
from syndb_api_client.models.new_dataset_schema import NewDatasetSchema
from syndb_api_client.models.o_auth2_authorize_response import OAuth2AuthorizeResponse
from syndb_api_client.models.pre_signed_s3_download_schema import PreSignedS3DownloadSchema
from syndb_api_client.models.pre_signed_s3_download_url_schema import PreSignedS3DownloadUrlSchema
from syndb_api_client.models.pre_signed_s3_upload_url_schema import PreSignedS3UploadUrlSchema
from syndb_api_client.models.publication_create_read import PublicationCreateRead
from syndb_api_client.models.response403_upload_dataset_files_neurodata_io_dataset_id_upload_patch import (
    Response403UploadDatasetFilesNeurodataIoDatasetIdUploadPatch,
)
from syndb_api_client.models.s3_instance import S3Instance
from syndb_api_client.models.s3_pre_signed_download_request import S3PreSignedDownloadRequest
from syndb_api_client.models.search_result_data_download import SearchResultDataDownload
from syndb_api_client.models.single_dataset_schema_no_brain_region import SingleDatasetSchemaNoBrainRegion
from syndb_api_client.models.syndb_error_model import SyndbErrorModel
from syndb_api_client.models.syndb_table import SyndbTable
from syndb_api_client.models.universal_metadata_response import UniversalMetadataResponse
from syndb_api_client.models.uploaded_single_dataset_schema import UploadedSingleDatasetSchema
from syndb_api_client.models.user_create import UserCreate
from syndb_api_client.models.user_metadata_response import UserMetadataResponse
from syndb_api_client.models.user_profile import UserProfile
from syndb_api_client.models.user_read import UserRead
from syndb_api_client.models.validation_error import ValidationError



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class BrainStructure(str, Enum):
    """
    BrainStructure
    """

    """
    allowed enum values
    """
    AMYGDALOID_COMPLEX = "amygdaloid complex"
    ANSA_LENTICULARIS = "ansa lenticularis"
    ARACHNOID_MATER = "arachnoid mater"
    ARBOR_VITAE = "arbor vitae"
    ARCUATE_FASCICULUS = "arcuate fasciculus"
    BASILAR_ARTERY = "basilar artery"
    BASONUCLEUS_AMYGDALA = "basonucleus amygdala"
    BERGMANN_GLIA = "bergmann glia"
    BERNASCONI_VEIN = "bernasconi vein"
    BLOOD_BRAIN_BARRIER = "blood brain barrier"
    BLOOD_VESSELS = "blood vessels"
    BODY_OF_FORNIX = "body of fornix"
    BRACHIUM_CONJUNCTIVUM = "brachium conjunctivum"
    BRAIN_BARRIER_SYSTEM = "brain barrier system"
    CA1 = "ca1"
    CA2 = "ca2"
    CA3 = "ca3"
    CA4 = "ca4"
    CALCARINE_SULCUS = "calcarine sulcus"
    CALLOSAL_SULCUS = "callosal sulcus"
    CALLOSOMARGINAL_ARTERY = "callosomarginal artery"
    CAUDATE = "caudate"
    CAUDATE_NUCLEUS = "caudate nucleus"
    CAVERNOSUS_SINUS = "cavernosus sinus"
    CAVE_OF_RETZIUS = "cave of retzius"
    CENTRAL_ARTERY = "central artery"
    CENTRAL_CANAL = "central canal"
    CENTRAL_LOBULE = "central lobule"
    CENTRAL_NUCLEUS_AMYGDALA = "central nucleus amygdala"
    CEREBELLAR_ARTERY = "cerebellar artery"
    CEREBELLAR_CORTEX = "cerebellar cortex"
    CEREBELLAR_NUCLEI = "cerebellar nuclei"
    CEREBELLAR_TONSIL = "cerebellar tonsil"
    CEREBELLAR_PEDUNCLES = "cerebellar peduncles"
    CEREBELLAR_PEDUNCLES_MIDDLE = "cerebellar peduncles middle"
    CEREBELLAR_VESSELS = "cerebellar vessels"
    CEREBELLAR_WHITE_MATTER = "cerebellar white matter"
    CEREBRAL_AQUEDUCT = "cerebral aqueduct"
    CEREBRAL_ARTERY = "cerebral artery"
    CEREBRAL_ENDOTHELIAL_CELL = "cerebral endothelial cell"
    CEREBRAL_VEIN = "cerebral vein"
    CEREBRAL_VESSELS = "cerebral vessels"
    CEREBROSPINAL_FLUID = "cerebrospinal fluid"
    CHOROIDAL_ARTERY = "choroidal artery"
    CHOROID_PLEXUS = "choroid plexus"
    CHOROID_PLEXUS_EPITHELIUM = "choroid plexus epithelium"
    CHOROID_PLEXUS_VESSELS = "choroid plexus vessels"
    CINGULATE = "cingulate"
    CINGULUM = "cingulum"
    CIRCLE_OF_WILLIS = "circle of willis"
    CIRCUMFLEX_FASCICULUS = "circumflex fasciculus"
    COLICULUS = "coliculus"
    COLSULCUS = "colsulcus"
    COLUMN_OF_FORNIX = "column of fornix"
    COMMISSURE = "commissure"
    COMMISSURE_WHITE_MATTER = "commissure white matter"
    COMMISURE = "commisure"
    COMMUNICATING_ARTERY = "communicating artery"
    CORPUS_CALLOSUM_BODY = "corpus callosum body"
    CORPUS_CALLOSUM_GENU = "corpus callosum genu"
    CORPUS_CALLOSUM_ROSTRUM = "corpus callosum rostrum"
    CORPUS_CALLOSUM_SPLENIUM = "corpus callosum splenium"
    CORTEX = "cortex"
    CORTICAL_NUCLEUS_AMYGDALA = "cortical nucleus amygdala"
    CORTICOSPINAL_TRACT = "corticospinal tract"
    CRUS_CEREBRI = "crus cerebri"
    CRUS_OF_FORNIX = "crus of fornix"
    CULMEN = "culmen"
    CULMEN_VERMIS = "culmen vermis"
    CUNEUS = "cuneus"
    DECLIVE = "declive"
    DECLIVE_VERMIS = "declive vermis"
    DENDRITE = "dendrite"
    DENTATE_GYRUS = "dentate gyrus"
    DENTATE_GYRUS_SULCUS = "dentate gyrus sulcus"
    DENTATE_NUCLEUS = "dentate nucleus"
    DG = "dg"
    DIAGONAL_BAND_OF_BROCA = "diagonal band of broca"
    DURA_MATER = "dura mater"
    EMBOLIFORM_NUCLEUS = "emboliform nucleus"
    ENTORHINAL_CORTEX = "entorhinal cortex"
    EPENDYMAL_CELL = "ependymal cell"
    EPENDYMOGLIA = "ependymoglia"
    FASTIGIAL_NUCLEUS = "fastigial nucleus"
    FASTIGIUM = "fastigium"
    FIBROUS_ASTROCYTE = "fibrous astrocyte"
    FIMBRIA = "fimbria"
    FISSURE_OF_SYLVIUS = "fissure of sylvius"
    FLOCCULONODULAR_LOBE = "flocculonodular lobe"
    FLOCCULUS = "flocculus"
    FOLLICULI = "folliculi"
    FORAMEN_OF_MONRO = "foramen of monro"
    FORCEPS_MAJOR = "forceps major"
    FORCEPS_MINOR = "forceps minor"
    FOURTH_VENTRICLE = "fourth ventricle"
    FRONTAL_GYRUS = "frontal gyrus"
    FRONTAL_SULCUS = "frontal sulcus"
    FRONTOPOLAR_ARTERY = "frontopolar artery"
    FUNICULUSIS = "funiculusis"
    GENICULATE_NUCLEUS = "geniculate nucleus"
    GLOBOSE_NUCLEUS = "globose nucleus"
    GLOBUS_PALLIDUS = "globus pallidus"
    HABENULA = "habenula"
    HABENULAR_COMMISURE = "habenular commisure"
    HIPPOCAMPAL_SULCUS = "hippocampal sulcus"
    HIPPOCAMPUS = "hippocampus"
    HYPOTHALAMIC_COMMISSURE = "hypothalamic commissure"
    HYPOTHALAMIC_COMMISURE = "hypothalamic commisure"
    INDUSEUM_GRISIUM = "induseum grisium"
    INFUNDIBULUM = "infundibulum"
    INTERCALATED_NUCLEUS_AMYGDALA = "intercalated nucleus amygdala"
    INTERIOR_CEREBRAL_VEIN = "interior cerebral vein"
    INTERNAL_CAPSULE_GENU = "internal capsule genu"
    INTERNAL_CAPSULE_LIMB = "internal capsule limb"
    INTERNAL_CAROTID_ARTERY = "internal carotid artery"
    INTERPEDUNCULAR_FOSSA = "interpeduncular fossa"
    INTERPOSITUS_NUCLEUS = "interpositus nucleus"
    INTERVENTRICULAR_FORAMEN = "interventricular foramen"
    INTRALAMINAR_NUCLEUS_THALAMUS = "intralaminar nucleus thalamus"
    LAMINA_TERMINALIS = "lamina terminalis"
    LATERONUCLEUS = "lateronucleus"
    LEMNISCUS = "lemniscus"
    LENTICULAR_FASCICULUS = "lenticular fasciculus"
    LENTICULOSTRIATE_ARTERIES = "lenticulostriate arteries"
    LINGUAL_GYRUS = "lingual gyrus"
    LINGUAL_SULCUS = "lingual sulcus"
    LONGITUDINAL_FASCICULUS = "longitudinal fasciculus"
    LUSHKA_FORAMEN = "lushka foramen"
    MAGENDIE_FORAMEN = "magendie foramen"
    MAMMILLARY_BODY = "mammillary body"
    MAMMILLARY_RECESS = "mammillary recess"
    MASSA_INTERMEDIA = "massa intermedia"
    MEDULLARY_RETICULOSPINAL_TRACT = "medullary reticulospinal tract"
    MEDULLARY_VELUM = "medullary velum"
    MENINGEAL_VESSELS = "meningeal vessels"
    MIDDLE_CEREBRAL_ARTERY = "middle cerebral artery"
    MIDDLE_CEREBRAL_VEIN = "middle cerebral vein"
    MIDDLE_TEMPORAL_GYRUS = "middle temporal gyrus"
    MIDLINE_NUCLEUS_THALAMUS = "midline nucleus thalamus"
    NUCLEUS_AMYGDALA = "nucleus amygdala"
    NUCLEUS_THALAMUS = "nucleus thalamus"
    NUCLEUS_ACCUMBENS = "nucleus accumbens"
    OCCIPITAL_GYRUS = "occipital gyrus"
    OCCIPITAL_SINUS = "occipital sinus"
    OCCIPITAL_SULCUS = "occipital sulcus"
    OCCIPITOTEMPORAL_GYRUS = "occipitotemporal gyrus"
    OCCIPITOTEMPORAL_SULCUS = "occipitotemporal sulcus"
    OLFACTORY_SULCUS = "olfactory sulcus"
    OLFACTORY_TRIGONE = "olfactory trigone"
    OLIGODENDROCYTE = "oligodendrocyte"
    OLIVARY_COMPLEX = "olivary complex"
    OLIVOSPINAL_TRACT = "olivospinal tract"
    OPHTHALMIC_ARTERY = "ophthalmic artery"
    OPTIC_CHIASM = "optic chiasm"
    OPTIC_NERVE = "optic nerve"
    OPTIC_RECESS = "optic recess"
    ORBIFRONTAL_GYRUS = "orbifrontal gyrus"
    ORBITOFRONTAL_ARTERY = "orbitofrontal artery"
    ORBITOFRONTAL_CORTEX = "orbitofrontal cortex"
    PARACENTRAL_LOBULE = "paracentral lobule"
    PARAFLOCCULUS = "paraflocculus"
    PARAHIPPOCAMPAL_GYRUS = "parahippocampal gyrus"
    PARAVENTRICULAR_NUCLEUS_THALAMUS = "paraventricular nucleus thalamus"
    PARENCHYMAL_FEET = "parenchymal feet"
    PARIETAL_GYRUS = "parietal gyrus"
    PARIETAL_LOBE = "parietal lobe"
    PARIETAL_LOBULE = "parietal lobule"
    PARIETAL_OPERCULUM = "parietal operculum"
    PARIETO_OCCIPITAL_ARTERY = "parieto occipital artery"
    PARIETO_OCCIPITAL_NOTCH = "parieto occipital notch"
    PARIETO_OCCIPITAL_SULCUS = "parieto occipital sulcus"
    PARS_OPERCULARIS = "pars opercularis"
    PARS_ORBITALIS = "pars orbitalis"
    PARS_TRIANGULARIS = "pars triangularis"
    PEDUNCULOPONTINE_NUCLEUS = "pedunculopontine nucleus"
    PERFORATED_SUBSTANCE = "perforated substance"
    PERICALLOSAL_ARTERY = "pericallosal artery"
    PERIRHINAL_CORTEX = "perirhinal cortex"
    PETROSAL_SINUS = "petrosal sinus"
    PIASTROCYTE = "piastrocyte"
    PIA_MATER = "pia mater"
    PINEALOCYTE = "pinealocyte"
    PINEAL_GYRUS = "pineal gyrus"
    PINEAL_RECESS = "pineal recess"
    PITUICYTE = "pituicyte"
    PITUITARY_GYRUS = "pituitary gyrus"
    PONS = "pons"
    PONTINE_FIBERS = "pontine fibers"
    PONTINE_RETICULOSPINAL_TRACT = "pontine reticulospinal tract"
    POSTCENTRAL_ARTERY = "postcentral artery"
    POSTCENTRAL_GYRUS = "postcentral gyrus"
    PRECENTRAL_ARTERY = "precentral artery"
    PRECENTRAL_GYRUS = "precentral gyrus"
    PRECENTRAL_SULCUS = "precentral sulcus"
    PRECUNEUS = "precuneus"
    PREMOTOR_CORTEX = "premotor cortex"
    PREOPTIC_AREA = "preoptic area"
    PREPYRIFORM_AREA = "prepyriform area"
    PRESUBICULUM = "presubiculum"
    PRIMARY_AUDITORY_CORTEX = "primary auditory cortex"
    PRIMARY_FISSURE = "primary fissure"
    PRIMARY_MOTOR_CORTEX = "primary motor cortex"
    PRIMARY_SENSORY_CORTEX = "primary sensory cortex"
    PRIMARY_SOMATOSENSORY_CORTEX = "primary somatosensory cortex"
    PRIMARY_VISUAL_CORTEX = "primary visual cortex"
    PRIMAR_VISUAL_CORTEX = "primar visual cortex"
    PROSUBICULUM = "prosubiculum"
    PROTOPLASMIC_ASTROCYTE = "protoplasmic astrocyte"
    PULVINAR = "pulvinar"
    PULVINAR_NUCLEUS = "pulvinar nucleus"
    PUTAMEN = "putamen"
    PYRAMIDAL_CELL = "pyramidal cell"
    PYRAMIDAL_TRACT = "pyramidal tract"
    PYRAMIS = "pyramis"
    PYRAMIS_VERMIS = "pyramis vermis"
    RADIAL_GLIA = "radial glia"
    RECESS = "recess"
    RECURRENT_ARTERY_OF_HEBERDEN = "recurrent artery of heberden"
    RED_NUCLEUS = "red nucleus"
    RETICULAR_FORMATION = "reticular formation"
    RETICULAR_NUCLEUS = "reticular nucleus"
    RETICULAR_NUCLEUS_THALAMUS = "reticular nucleus thalamus"
    RETROLENFICULAR_PART = "retrolenficular part"
    RETROSPLENIAL_CORTEX = "retrosplenial cortex"
    RHINAL_SULCUS = "rhinal sulcus"
    RHOMBIC_LIP = "rhombic lip"
    ROSSENTHAL_VEIN = "rossenthal vein"
    RUBROSPINAL_TRACT = "rubrospinal tract"
    SAGITTAL_SINUS = "sagittal sinus"
    SECONDARY_AUDITORY_CORTEX = "secondary auditory cortex"
    SECONDARY_SOMATOSENSORY_CORTEX = "secondary somatosensory cortex"
    SECONDARY_VISUAL_CORTEX = "secondary visual cortex"
    SEPTAL_NUCLEUS = "septal nucleus"
    SEPTUM = "septum"
    SEPTUM_PELLUCIDUM = "septum pellucidum"
    SEPTUM_VERUM = "septum verum"
    SHORT_CINGULATE_GYRUS = "short cingulate gyrus"
    SHORT_INSULAR_GYRUS = "short insular gyrus"
    SIGMOID_SINUS = "sigmoid sinus"
    SILVIAN_FISSURE = "silvian fissure"
    SIMPLE_LOBULE = "simple lobule"
    SINGULATE = "singulate"
    SINGULATE_GYRUS = "singulate gyrus"
    SINGULATE_SULCUS = "singulate sulcus"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BrainStructure from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from typing import Any, Dict, List, Optional, Tuple, Union

from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call
from syndb_api_client.api_client import ApiClient, RequestSerialized
from syndb_api_client.api_response import ApiResponse
from syndb_api_client.models.o_auth2_authorize_response import OAuth2AuthorizeResponse
from syndb_api_client.rest import RESTResponseType
from typing_extensions import Annotated


class GoogleApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get(
        self,
        scopes: Optional[List[StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OAuth2AuthorizeResponse:
        """Oauth:Google.Db-Google.Authorize


        :param scopes:
        :type scopes: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get_serialize(
            scopes=scopes,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "OAuth2AuthorizeResponse",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get_with_http_info(
        self,
        scopes: Optional[List[StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OAuth2AuthorizeResponse]:
        """Oauth:Google.Db-Google.Authorize


        :param scopes:
        :type scopes: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get_serialize(
            scopes=scopes,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "OAuth2AuthorizeResponse",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get_without_preload_content(
        self,
        scopes: Optional[List[StrictStr]] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Oauth:Google.Db-Google.Authorize


        :param scopes:
        :type scopes: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get_serialize(
            scopes=scopes,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "OAuth2AuthorizeResponse",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _oauth_google_db_google_authorize_user_auth_oauth_google_authorize_get_serialize(
        self,
        scopes,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            "scopes": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if scopes is not None:

            _query_params.append(("scopes", scopes))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/user/auth/oauth/google/authorize",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def oauth_google_db_google_callback_user_auth_oauth_google_callback_get(
        self,
        code: Optional[StrictStr] = None,
        code_verifier: Optional[StrictStr] = None,
        state: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Oauth:Google.Db-Google.Callback

        The response varies based on the authentication backend used.

        :param code:
        :type code: str
        :param code_verifier:
        :type code_verifier: str
        :param state:
        :type state: str
        :param error:
        :type error: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._oauth_google_db_google_callback_user_auth_oauth_google_callback_get_serialize(
            code=code,
            code_verifier=code_verifier,
            state=state,
            error=error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "400": "ErrorModel",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def oauth_google_db_google_callback_user_auth_oauth_google_callback_get_with_http_info(
        self,
        code: Optional[StrictStr] = None,
        code_verifier: Optional[StrictStr] = None,
        state: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Oauth:Google.Db-Google.Callback

        The response varies based on the authentication backend used.

        :param code:
        :type code: str
        :param code_verifier:
        :type code_verifier: str
        :param state:
        :type state: str
        :param error:
        :type error: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._oauth_google_db_google_callback_user_auth_oauth_google_callback_get_serialize(
            code=code,
            code_verifier=code_verifier,
            state=state,
            error=error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "400": "ErrorModel",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def oauth_google_db_google_callback_user_auth_oauth_google_callback_get_without_preload_content(
        self,
        code: Optional[StrictStr] = None,
        code_verifier: Optional[StrictStr] = None,
        state: Optional[StrictStr] = None,
        error: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Oauth:Google.Db-Google.Callback

        The response varies based on the authentication backend used.

        :param code:
        :type code: str
        :param code_verifier:
        :type code_verifier: str
        :param state:
        :type state: str
        :param error:
        :type error: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._oauth_google_db_google_callback_user_auth_oauth_google_callback_get_serialize(
            code=code,
            code_verifier=code_verifier,
            state=state,
            error=error,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "400": "ErrorModel",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _oauth_google_db_google_callback_user_auth_oauth_google_callback_get_serialize(
        self,
        code,
        code_verifier,
        state,
        error,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if code is not None:

            _query_params.append(("code", code))

        if code_verifier is not None:

            _query_params.append(("code_verifier", code_verifier))

        if state is not None:

            _query_params.append(("state", state))

        if error is not None:

            _query_params.append(("error", error))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/user/auth/oauth/google/callback",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, StrictStr
from syndb_api_client.models.multi_brain_region_dataset_definition import MultiBrainRegionDatasetDefinition
from syndb_api_client.models.single_dataset_schema_no_brain_region import SingleDatasetSchemaNoBrainRegion
from typing_extensions import Self


class CreateDatasetCollectionMultiBrainRegion(BaseModel):
    """
    CreateDatasetCollectionMultiBrainRegion
    """  # noqa: E501

    authorized_group_names: Optional[List[StrictStr]] = None
    name: StrictStr
    notes: Optional[StrictStr] = None
    dataset_definition: List[MultiBrainRegionDatasetDefinition]
    dataset_metadata: SingleDatasetSchemaNoBrainRegion
    __properties: ClassVar[List[str]] = [
        "authorized_group_names",
        "name",
        "notes",
        "dataset_definition",
        "dataset_metadata",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateDatasetCollectionMultiBrainRegion from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in dataset_definition (list)
        _items = []
        if self.dataset_definition:
            for _item in self.dataset_definition:
                if _item:
                    _items.append(_item.to_dict())
            _dict["dataset_definition"] = _items
        # override the default output from pydantic by calling `to_dict()` of dataset_metadata
        if self.dataset_metadata:
            _dict["dataset_metadata"] = self.dataset_metadata.to_dict()
        # set to None if authorized_group_names (nullable) is None
        # and model_fields_set contains the field
        if self.authorized_group_names is None and "authorized_group_names" in self.model_fields_set:
            _dict["authorized_group_names"] = None

        # set to None if notes (nullable) is None
        # and model_fields_set contains the field
        if self.notes is None and "notes" in self.model_fields_set:
            _dict["notes"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateDatasetCollectionMultiBrainRegion from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "authorized_group_names": obj.get("authorized_group_names"),
                "name": obj.get("name"),
                "notes": obj.get("notes"),
                "dataset_definition": (
                    [MultiBrainRegionDatasetDefinition.from_dict(_item) for _item in obj["dataset_definition"]]
                    if obj.get("dataset_definition") is not None
                    else None
                ),
                "dataset_metadata": (
                    SingleDatasetSchemaNoBrainRegion.from_dict(obj["dataset_metadata"])
                    if obj.get("dataset_metadata") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class NeuroanatomicalDirection(str, Enum):
    """
    NeuroanatomicalDirection
    """

    """
    allowed enum values
    """
    ANTERIOR = "anterior"
    ANTERIOR_DORSAL = "anterior dorsal"
    ANTERIOR_VENTRAL = "anterior ventral"
    CAUDAL = "caudal"
    DISTAL = "distal"
    DISTAL_CAUDAL = "distal caudal"
    DISTAL_ROSTRAL = "distal rostral"
    DORSAL = "dorsal"
    DORSAL_LATERAL = "dorsal lateral"
    DORSAL_MEDIAL = "dorsal medial"
    INFERIOR = "inferior"
    INFERIOR_DISTAL = "inferior distal"
    INFERIOR_PROXIMAL = "inferior proximal"
    LATERAL = "lateral"
    LATERAL_INFERIOR = "lateral inferior"
    LATERAL_SUPERIOR = "lateral superior"
    MEDIAL = "medial"
    MEDIAL_INFERIOR = "medial inferior"
    MEDIAL_SUPERIOR = "medial superior"
    POSTERIOR = "posterior"
    POSTERIOR_DORSAL = "posterior dorsal"
    POSTERIOR_VENTRAL = "posterior ventral"
    PROXIMAL = "proximal"
    PROXIMAL_CAUDAL = "proximal caudal"
    PROXIMAL_ROSTRAL = "proximal rostral"
    ROSTRAL = "rostral"
    SUPERIOR = "superior"
    SUPERIOR_DISTAL = "superior distal"
    SUPERIOR_PROXIMAL = "superior proximal"
    VENTRAL = "ventral"
    VENTRAL_LATERAL = "ventral lateral"
    VENTRAL_MEDIAL = "ventral medial"
    NULL = "null"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NeuroanatomicalDirection from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, StrictStr
from syndb_api_client.models.brain_region_read import BrainRegionRead
from syndb_api_client.models.cultural_model_animal_name import CulturalModelAnimalName
from syndb_api_client.models.data_license import DataLicense
from syndb_api_client.models.model_animal import ModelAnimal
from syndb_api_client.models.mutation_model_read import MutationModelRead
from syndb_api_client.models.syndb_table import SyndbTable
from typing_extensions import Self


class DatasetFilterSchema(BaseModel):
    """
    DatasetFilterSchema
    """  # noqa: E501

    authorized_group_names: Optional[List[StrictStr]] = None
    dataset_collection_names: Optional[List[StrictStr]] = None
    publication_dois: Optional[List[StrictStr]] = None
    syndb_tables: Optional[List[SyndbTable]] = None
    data_licenses: Optional[List[DataLicense]] = None
    animals_species: Optional[List[ModelAnimal]] = None
    animal_cultural_names: Optional[List[CulturalModelAnimalName]] = None
    mutations: Optional[List[MutationModelRead]] = None
    brain_regions: Optional[List[BrainRegionRead]] = None
    microscopy_names: Optional[List[StrictStr]] = None
    owner_id: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = [
        "authorized_group_names",
        "dataset_collection_names",
        "publication_dois",
        "syndb_tables",
        "data_licenses",
        "animals_species",
        "animal_cultural_names",
        "mutations",
        "brain_regions",
        "microscopy_names",
        "owner_id",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DatasetFilterSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in mutations (list)
        _items = []
        if self.mutations:
            for _item in self.mutations:
                if _item:
                    _items.append(_item.to_dict())
            _dict["mutations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in brain_regions (list)
        _items = []
        if self.brain_regions:
            for _item in self.brain_regions:
                if _item:
                    _items.append(_item.to_dict())
            _dict["brain_regions"] = _items
        # set to None if authorized_group_names (nullable) is None
        # and model_fields_set contains the field
        if self.authorized_group_names is None and "authorized_group_names" in self.model_fields_set:
            _dict["authorized_group_names"] = None

        # set to None if dataset_collection_names (nullable) is None
        # and model_fields_set contains the field
        if self.dataset_collection_names is None and "dataset_collection_names" in self.model_fields_set:
            _dict["dataset_collection_names"] = None

        # set to None if publication_dois (nullable) is None
        # and model_fields_set contains the field
        if self.publication_dois is None and "publication_dois" in self.model_fields_set:
            _dict["publication_dois"] = None

        # set to None if syndb_tables (nullable) is None
        # and model_fields_set contains the field
        if self.syndb_tables is None and "syndb_tables" in self.model_fields_set:
            _dict["syndb_tables"] = None

        # set to None if data_licenses (nullable) is None
        # and model_fields_set contains the field
        if self.data_licenses is None and "data_licenses" in self.model_fields_set:
            _dict["data_licenses"] = None

        # set to None if animals_species (nullable) is None
        # and model_fields_set contains the field
        if self.animals_species is None and "animals_species" in self.model_fields_set:
            _dict["animals_species"] = None

        # set to None if animal_cultural_names (nullable) is None
        # and model_fields_set contains the field
        if self.animal_cultural_names is None and "animal_cultural_names" in self.model_fields_set:
            _dict["animal_cultural_names"] = None

        # set to None if mutations (nullable) is None
        # and model_fields_set contains the field
        if self.mutations is None and "mutations" in self.model_fields_set:
            _dict["mutations"] = None

        # set to None if brain_regions (nullable) is None
        # and model_fields_set contains the field
        if self.brain_regions is None and "brain_regions" in self.model_fields_set:
            _dict["brain_regions"] = None

        # set to None if microscopy_names (nullable) is None
        # and model_fields_set contains the field
        if self.microscopy_names is None and "microscopy_names" in self.model_fields_set:
            _dict["microscopy_names"] = None

        # set to None if owner_id (nullable) is None
        # and model_fields_set contains the field
        if self.owner_id is None and "owner_id" in self.model_fields_set:
            _dict["owner_id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DatasetFilterSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "authorized_group_names": obj.get("authorized_group_names"),
                "dataset_collection_names": obj.get("dataset_collection_names"),
                "publication_dois": obj.get("publication_dois"),
                "syndb_tables": obj.get("syndb_tables"),
                "data_licenses": obj.get("data_licenses"),
                "animals_species": obj.get("animals_species"),
                "animal_cultural_names": obj.get("animal_cultural_names"),
                "mutations": (
                    [MutationModelRead.from_dict(_item) for _item in obj["mutations"]]
                    if obj.get("mutations") is not None
                    else None
                ),
                "brain_regions": (
                    [BrainRegionRead.from_dict(_item) for _item in obj["brain_regions"]]
                    if obj.get("brain_regions") is not None
                    else None
                ),
                "microscopy_names": obj.get("microscopy_names"),
                "owner_id": obj.get("owner_id"),
            }
        )
        return _obj



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Annotated, Self


class NeurodataDownloadBenchmarkResultSchema(BaseModel):
    """
    NeurodataDownloadBenchmarkResultSchema
    """  # noqa: E501

    creation_datetime: datetime
    payload_byte_size: StrictInt
    speed: StrictInt
    interval: StrictStr
    continent: Optional[StrictStr]
    country_alpha2: Optional[Annotated[str, Field(strict=True)]]
    city: Optional[StrictStr]
    dataset_ids: List[StrictStr]
    __properties: ClassVar[List[str]] = [
        "creation_datetime",
        "payload_byte_size",
        "speed",
        "interval",
        "continent",
        "country_alpha2",
        "city",
        "dataset_ids",
    ]

    @field_validator("country_alpha2")
    def country_alpha2_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^\w{2}$", value):
            raise ValueError(r"must validate the regular expression /^\w{2}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NeurodataDownloadBenchmarkResultSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if continent (nullable) is None
        # and model_fields_set contains the field
        if self.continent is None and "continent" in self.model_fields_set:
            _dict["continent"] = None

        # set to None if country_alpha2 (nullable) is None
        # and model_fields_set contains the field
        if self.country_alpha2 is None and "country_alpha2" in self.model_fields_set:
            _dict["country_alpha2"] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict["city"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NeurodataDownloadBenchmarkResultSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "creation_datetime": obj.get("creation_datetime"),
                "payload_byte_size": obj.get("payload_byte_size"),
                "speed": obj.get("speed"),
                "interval": obj.get("interval"),
                "continent": obj.get("continent"),
                "country_alpha2": obj.get("country_alpha2"),
                "city": obj.get("city"),
                "dataset_ids": obj.get("dataset_ids"),
            }
        )
        return _obj



# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class GeneExpression(str, Enum):
    """
    GeneExpression
    """

    """
    allowed enum values
    """
    KNOCK_MINUS_OUT = "knock-out"
    KNOCK_MINUS_IN = "knock-in"
    KNOCK_MINUS_DOWN = "knock-down"
    KNOCK_MINUS_SIDEWAYS = "knock-sideways"
    OVEREXPRESSION = "overexpression"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of GeneExpression from a JSON string"""
        return cls(json.loads(json_str))
